import "./styles/Layout.css";
import "./styles/extra.css";
import { useEffect, useState } from "react";
import { NavLink, Route, Routes, useNavigate } from "react-router-dom";
import Welcome from "./pages/Welcome";
import Navbar from "react-bootstrap/Navbar";
import { Container, Nav, NavbarBrand } from "react-bootstrap";
import NavbarToggle from "react-bootstrap/esm/NavbarToggle";
import NavbarCollapse from "react-bootstrap/esm/NavbarCollapse";
import Dashboard from "./pages/Dashboard";
import Logout from "./pages/Logout";
import Login from "./pages/Login";
import Context from "./globals.js";


export default function layout() {
    const [state, setState] = useState({
        user: null,
        setUser: setUser,
        navigate: useNavigate()
    });

    function setUser(user) {
        setState({ user: user });
    }

    let identityDisplay = (
        <Nav>
            <li className="nav-item">
                <NavLink className="nav-link" to="/login" >Login</NavLink>
            </li>
            <li className="nav-item">
                <NavLink className="nav-link" to="/signup" >Sign up!</NavLink>
            </li>
        </Nav>
    );

    if (state.user) {
        identityDisplay = (
            <Nav>
                <li className="nav-item">
                    <NavLink className="nav-link" to="/" >Hi, {state.user.firstName}</NavLink>
                </li>
                <li className="nav-item">
                    <NavLink className="nav-link" to="/logout" >Logout</NavLink>
                </li>
            </Nav>
        );
    }

    return (
        <div id="app">
            <Context.Provider value={state}>
                <header>
                    <Navbar bg="light" expand="md">
                        <Container>
                            <NavbarBrand href="/">Sports Matcher</NavbarBrand>
                            <NavbarToggle aria-controls="navigation"></NavbarToggle>
                            <NavbarCollapse id="main-nav">
                                <Nav className="me-auto">
                                    <li className="nav-item">
                                        <NavLink className="nav-link" to="/" >Home</NavLink>
                                    </li>
                                </Nav>
                                {identityDisplay}
                            </NavbarCollapse>
                        </Container>
                    </Navbar>
                </header>
                <main>
                    <Routes>
                        <Route path="/" element={<Welcome />} />
                        <Route path="/dashboard" element={<Dashboard />} />
                        <Route path="/login" element={<Login />} />
                        <Route path="/logout" element={<Logout />} />
                    </Routes>
                </main>
                <footer>

                </footer>
            </Context.Provider>
        </div>
    );
}